@@ -64,7 +64,7 @@ _TESTS_REQUIRE = [
 
 _SETUP = dict(
   name='m4us',
-  version='0.1',
+  version='0.1.1',
   description=('A pythonic coroutine-based concurrent programming framework '
     'inspired by Kamaelia.'),
   author='Krys Lawrence',
@@ -222,14 +222,9 @@ def _gen_docs(options, *option_sets):
 #---  Tasks
 
 @paver.task
-@paver.needs('clean', 'minilib', 'generate_setup', 'html',
-  'setuptools.command.sdist')
+@paver.needs('minilib', 'generate_setup', 'html', 'setuptools.command.sdist')
 def sdist():
     """Generate the source distribution."""
-    # Clean called a second time to clean up after the sdist generation.
-    ## pylint: disable=E1120
-    clean()
-    ## pylint: enable=E1120
 
 
 @paver.task
@@ -239,7 +234,6 @@ def release(options):
     egg_info_options['tag-build'] = ''
     egg_info_options['tag-date'] = False
     paver.call_task('setuptools.command.egg_info')
-    paver.call_task('sdist')
 
 
 @paver.task
